@@ -28,7 +28,7 @@ def test_fork_config(config, network):
     assert network_config.get("upstream_provider") == "alchemy", "config not registered"
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 @pytest.mark.parametrize("upstream_network,port", [("mainnet", 8998), ("goerli", 8999)])
 def test_impersonate(networks, accounts, upstream_network, port, create_fork_provider):
     provider = create_fork_provider(port=port, network=upstream_network)
@@ -46,7 +46,7 @@ def test_impersonate(networks, accounts, upstream_network, port, create_fork_pro
     networks.active_provider = orig_provider
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_request_timeout(networks, config, create_fork_provider):
     provider = create_fork_provider(9008)
     provider.connect()
@@ -63,7 +63,7 @@ def test_request_timeout(networks, config, create_fork_provider):
             assert provider.timeout == 300
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_reset_fork_no_fork_block_number(networks, create_fork_provider):
     provider = create_fork_provider(port=9013, network="goerli")
     provider.connect()
@@ -75,7 +75,7 @@ def test_reset_fork_no_fork_block_number(networks, create_fork_provider):
     provider.disconnect()
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_reset_fork_specify_block_number_via_argument(networks, create_fork_provider):
     provider = create_fork_provider(port=9020, network="goerli")
     provider.connect()
@@ -88,18 +88,18 @@ def test_reset_fork_specify_block_number_via_argument(networks, create_fork_prov
     provider.disconnect()
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_reset_fork_specify_block_number_via_config(networks, create_fork_provider):
     provider = create_fork_provider(port=9030)
     provider.connect()
     provider.mine(5)
     provider.reset_fork()
     block_num_after_reset = provider.get_block("latest").number
-    assert block_num_after_reset == 15000000  # Specified in ape-config.yaml
+    assert block_num_after_reset == 15776634  # Specified in ape-config.yaml
     provider.disconnect()
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_transaction(owner, fork_contract_instance):
     receipt = fork_contract_instance.setNumber(6, sender=owner)
     assert receipt.sender == owner
@@ -108,42 +108,36 @@ def test_transaction(owner, fork_contract_instance):
     assert value == 6
 
 
-@pytest.mark.fork
+@pytest.mark.sync
 def test_revert(sender, fork_contract_instance):
     # 'sender' is not the owner so it will revert (with a message)
-    with pytest.raises(ContractLogicError) as err:
+    with pytest.raises(ContractLogicError, match="!authorized"):
         fork_contract_instance.setNumber(6, sender=sender)
 
-    assert str(err.value) == "!authorized"
 
-
-@pytest.mark.fork
+@pytest.mark.sync
 def test_contract_revert_no_message(owner, fork_contract_instance, connected_mainnet_fork_provider):
     # Set balance so test wouldn't normally fail from lack of funds
     connected_mainnet_fork_provider.set_balance(fork_contract_instance.address, "1000 ETH")
 
     # The Contract raises empty revert when setting number to 5.
-    with pytest.raises(ContractLogicError) as err:
+    with pytest.raises(ContractLogicError, match="Transaction failed."):
         fork_contract_instance.setNumber(5, sender=owner)
 
-    assert str(err.value) == "Transaction failed."
 
-
-@pytest.mark.fork
+@pytest.mark.sync
 def test_transaction_contract_as_sender(
     fork_contract_instance, connected_mainnet_fork_provider, convert
 ):
     # Set balance so test wouldn't normally fail from lack of funds
     connected_mainnet_fork_provider.set_balance(fork_contract_instance.address, "1000 ETH")
 
-    with pytest.raises(ContractLogicError) as err:
+    with pytest.raises(ContractLogicError, match="!authorized"):
         # Task failed successfully
         fork_contract_instance.setNumber(10, sender=fork_contract_instance)
 
-    assert str(err.value) == "!authorized"
 
-
-@pytest.mark.fork
+@pytest.mark.sync
 def test_transaction_unknown_contract_as_sender(accounts, networks, create_fork_provider):
     provider = create_fork_provider(9012)
     provider.connect()
@@ -153,3 +147,12 @@ def test_transaction_unknown_contract_as_sender(accounts, networks, create_fork_
     multi_sig = accounts[account]
     multi_sig.transfer(accounts[0], "100 gwei")
     networks.active_provider = init_provider
+
+
+@pytest.mark.sync
+def test_get_receipt(connected_mainnet_fork_provider, fork_contract_instance, owner):
+    receipt = fork_contract_instance.setAddress(owner.address, sender=owner)
+    actual = connected_mainnet_fork_provider.get_receipt(receipt.txn_hash)
+    assert receipt.txn_hash == actual.txn_hash
+    assert actual.receiver == fork_contract_instance.address
+    assert actual.sender == receipt.sender
